==> hlog-0.20-rc1.tar.gz: hlog-0.20-rc1/hlog/contest/script.h <==
/*
 * Copyright (c) 2020-2021 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#ifndef __SCRIPT_H
#define __SCRIPT_H

#include <hlog-lua/xlua.h>

#include "../common/xform.h"

struct contest_params {
	const char *name;
	uint32_t year;
};

extern int script_exists(const struct contest_params *params);
extern lua_State *script_load(struct xfield_def **fields, size_t *nwfields,
			      const struct contest_params *params);

/* events */
extern int script_event_field_change(lua_State *L, struct qso *qso,
				     struct xform *form, char *error,
				     size_t errlen,
				     void (*cb)(struct xform *, const char *,
						const char *));
extern int script_event_qso_init(lua_State *L, struct qso *qso,
				 char *error, size_t errlen);
extern int script_event_qso_done(lua_State *L, struct qso *qso,
				 char *error, size_t errlen);

#endif

==> hlog-0.21-rc1.tar.gz: hlog-0.21-rc1/hlog/contest/script.h <==
/*
 * Copyright (c) 2020-2022 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#ifndef __SCRIPT_H
#define __SCRIPT_H

#include <hlog-lua/xlua.h>

#include "../common/xform.h"

extern int script_exists(const struct contest_params *params);
extern lua_State *script_load(struct xfield_def **fields, size_t *nfields,
			      const struct contest_params *params,
			      struct qso *template);

/* events */
extern int script_event_field_change(lua_State *L, struct qso *qso,
				     struct xform *form, char *error,
				     size_t errlen,
				     void (*fcb)(struct xform *, const char *,
						 const char *),
				     void (*acb)(struct xform *, const char *,
						 const char *));
extern int script_event_qso_init(lua_State *L, struct qso *qso,
				 char *error, size_t errlen);
extern int script_event_qso_done(lua_State *L, struct qso *qso,
				 char *error, size_t errlen);

#endif
